<html>
<head>
  <title>%(listname)s %(who)s Authentication</title>
</head>
<body bgcolor="#ffffff">
<FORM METHOD=POST ACTION="%(path)s">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER"> <B><FONT COLOR="#000000" SIZE="+1">%(listname)s 
        %(who)s Autentificaci&oacute;</FONT></B></TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right"> Clau de pas de la llista de %(who)s :</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Entrar...">
      </td>
    </tr>
  </TABLE>
      
  <p><strong><em>Important:</em></strong> A partir d'aqu&iacute;, necessita tenir 
    les cookies habilitades en el seu navegador, d'altra manera cap canvi administratiu 
    pendr&agrave; efecte.
  <p>Les cookies de sessi&oacute; s'usen en la interf&iacute;cie administrativa 
    de Mailman, de manera que no necessita re-autentificar en cada operaci&oacute; 
    administrativa. Aquesta cookie expirar&agrave; autom&agrave;ticament quan 
    sorti del navegador, o b&eacute; vost&egrave; pot eliminar expl&iacute;citament 
    la cookie prement el link <em>Sortir</em> sota <em>Altres Activitats Administratives</em> 
    (el qual podreu veure un cop us hagueu registra't). 
</FORM>
</body>
</html>
