Aquesta p&agrave;gina cont&eacute; un sumari del conjunt actual de peticions administratives
que requereixen la seva aprovaci&oacute; per a <a href="%(adminurl)s"><em>%(listname)s</em> mailing list</a>.
Primer, trobar&aacute; una llista de les peticions pendents d'altes i baixes, si &eacute;s que n'hi alguna, 
seguit dels missatges retinguts per a la seva aprobaci&oacute;.

<p>Per a qualsevol petici&oacute; administrativa, si us plau seleccioni l'acci&oacute; a seguir
fent click sobre el bot&oacute; <b>Enviar totes les dades</b> quan hagi acabat.
També hi ha disponibles <a href="%(detailsurl)s">instruccions m&eacute;s detallades</a>.

<p>Pot tamb&eacute; <a href="%(viewallurl)s">veure els detalls</a> de tots els 
  missatges retinguts.
