Her finder du en oversigt over forespørgsler der skal vurderes til maillisten.
<a href="%(adminurl)s"><em>%(listname)s</em></a>.<br>
Eventuelle an&oslash;gninger om medlemsskab til listen vil blive
vist f&oslash;rst, derefter kommer meddelelser som er sendt til listen
men som venter pa godkendelse for at blive rundsendt.

<p>For hver foresp&oslash;rgsel, v&aelig;lg &oslash;nsket tiltag, og klik p&aring; <b>Udf&oslash;re</b> knappen n&aring;r du er f&aelig;rdig.
<a href="%(detailsurl)s">N&aelig;rmere instruktioner</a> er ogs&aring; tilg&aelig;ngelige.

<p>Du kan ogs&aring; <a href="%(viewallurl)s">vise alle detaljer for alle tilbageholdte meddelelser</a> hvis du &oslash;nsker det.
